@@ -21,6 +21,9 @@ config.suffixes = ['.cl', '.ll', '.spt', '.spvasm']
 # excludes: A list of directories  and fles to exclude from the testsuite.
 config.excludes = ['CMakeLists.txt']
 
+if config.spirv_tools_found:
+    config.available_features.add('libspirv_dis')
+
 if not config.spirv_skip_debug_info_tests:
     # Direct object generation.
     config.available_features.add('object-emission')
